@@ -2,7 +2,7 @@ package Gtk2::Ex::DbLinker::AbForm;
 use Class::InsideOut qw(public private register id);
 use Gtk2::Ex::DbLinker::DbTools;
 use Scalar::Util qw(weaken);
-use Carp 'croak';
+#use Carp 'croak';
 our $VERSION = $Gtk2::Ex::DbLinker::DbTools::VERSION;
 =head1 NAME
 
@@ -16,9 +16,9 @@ See L<Gtk2::Ex::DbLinker::Form> and L<Wx::Perl::DbLinker::Wxform>. The methods i
 
 use strict;
 use warnings;
-use Data::Dumper;
+#use Data::Dumper;
 use DateTime::Format::Strptime;
-use Carp qw(confess);
+#use Carp qw(confess);
 
 private data_manager => my %dman;
 public child_class => my %child_class;
@@ -115,7 +115,7 @@ sub set_data_manager {
     $dman{ id $self } = $dman;
 }
 
-=item C<add_childform( $childform )>
+=head2 C<add_childform( $childform )>
 
 You may add any dependant form or datasheet object with this call if you want that a changed in this subform/datasheet be applied when the apply method of this form is called. 
 
@@ -199,28 +199,32 @@ sub _datawidgetsName {
 
 sub _cols {
     my $self = shift;
-  confess __PACKAGE__ . "_cols is readonly" if (defined $_[0]);
-    return  $widgets{ id $self}->{cols};
+    my $id =  id $self; 
+  $log{ $id }->logconfess( __PACKAGE__ . "_cols is readonly") if (defined $_[0]);
+    return  $widgets{ $id }->{cols};
 }
 
 sub _dman {
      my $self = shift;
-     confess __PACKAGE__ . "_dman is readonly" if (defined $_[0]);
-    return  $dman{ id $self};
+     my $id =  id $self;
+     $log{ $id }->logconfess( __PACKAGE__ . "_dman is readonly") if (defined $_[0]);
+    return  $dman{ $id };
 
 }
 
 sub _pos {
      my $self = shift;
-     confess __PACKAGE__ . "_pos is readonly" if (defined $_[0]);
-    return  $states{ id $self}->{pos};
+    my $id =  id $self;
+     $log{ $id }->logconfess( __PACKAGE__ . "_pos is readonly") if (defined $_[0]);
+    return  $states{ $id }->{pos};
 
 }
 
 sub _auto_apply {
      my $self = shift;
-      confess __PACKAGE__ . "_auto_apply is readonly" if (defined $_[0]);
-    return  $states{ id $self }->{auto_apply};
+     my $id =  id $self;
+      $log{ $id }->logconfess( __PACKAGE__ . "_auto_apply is readonly") if (defined $_[0]);
+    return  $states{ $id }->{auto_apply};
 }
 
 sub _display_data {
@@ -367,8 +371,7 @@ sub insert {
 		 #ne pas appler _rs_on_changed ici
         	$self->{rec_spinner}->SetValue($new_pos+1);
 		#$self->{rec_spinner}->signal_handler_unblock( $self->{rs_value_changed_signal} );
-		 
-    
+
     	} 
 =cut
 
@@ -398,9 +401,7 @@ sub undo {
 		$self->{rec_spinner}->signal_handler_block( $self->{rs_value_changed_signal} );
        		$self->{rec_spinner}->set_value($self->{pos} + 1);
 		#$self->{rec_spinner}->SetValue($self->{pos} + 1);
-	        $self->{rec_spinner}->signal_handler_unblock( $self->{rs_value_changed_signal} );
-
-	
+	        $self->{rec_spinner}->signal_handler_unblock( $self->{rs_value_changed_signal} );	
 	}
 =cut
 
@@ -577,7 +578,7 @@ sub _update_fields {
                 $log{ $id }->debug( $widgets{ $id }->{datawidgetsName}->{$idcol} );
                 my %getter  = $child_class{ $id }->_get_getter;
                 my $coderef = $getter{ $widgets{ $id }->{datawidgetsName}->{$idcol} };
-                $log{ $id }->debug(Dumper $coderef);
+                #$log{ $id }->debug(Dumper $coderef);
                 #$idcol only used by Wxform
                 my $v = &$coderef( $self, $w, $idcol );
                 $log{ $id }->debug(
@@ -742,11 +743,11 @@ sub _format_date {
     my ( $pos1, $pos2 ) = ( $in_db ? ( 1, 0 ) : ( 0, 1 ) );
     my $format = $widgets{ $id }->{date_formatters}->{$idcol}->[$pos1];
     my $f      = $self->_get_dateformatter($format);
-    my $dt     = $f->parse_datetime($v) or croak( $f->errmsg );
+    my $dt     = $f->parse_datetime($v) or $log{ $id }->logcroak( $f->errmsg );
     $log{ $id }->debug( "format_date:  date time object ymd: " . $dt->ymd );
     $format = $widgets{ $id }->{date_formatters}->{$idcol}->[$pos2];
     $f      = $self->_get_dateformatter($format);
-    my $r = $f->format_datetime($dt) or croak( $f->errmsg );
+    my $r = $f->format_datetime($dt) or $log{ $id }->logcroak( $f->errmsg );
     $log{ $id }->debug( "format_date formatted date: " . $r );
 
     return $r;
@@ -806,7 +807,7 @@ FranE<ccedil>ois Rappaz <rappazf@gmail.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014 by F. Rappaz.  All rights reserved.
+Copyright (c) 2014-2017 by F. Rappaz.  All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
