@@ -15,8 +15,8 @@ See L<Gtk2::Ex::DbLinker::Datasheet> and L<Wx::Perl::DbLinker::Wxdatasheet>.
 
 use strict;
 use warnings;
-use Carp qw(confess);
-use Data::Dumper;
+# use Carp qw(confess);
+# use Data::Dumper;
 
 use constant {
     UNCHANGED     => 0,
@@ -70,8 +70,8 @@ sub new {
     my $self;
     @$self{ keys %arg } = values(%arg);
     bless $self, $class;
-    confess( __PACKAGE__, " new : ", join( " ", @$missing ), " keys with values missing" ) if ( defined( $missing = $self->_get_missing_arg( \%arg, [qw(cols dman)] ) ) );
-    $self->{log} = Log::Log4perl->get_logger(__PACKAGE__);
+     $self->{log} = Log::Log4perl->get_logger(__PACKAGE__);
+    $self->{log}->logconfess( __PACKAGE__, " new : ", join( " ", @$missing ), " keys with values missing" ) if ( defined( $missing = $self->_get_missing_arg( \%arg, [qw(cols dman)] ) ) );
     $self->{log}->debug("new called ** cols are ", join(" ", @{ $self->{cols}}) );
     my %hcols = map { $_ => 1 } @{ $self->{cols} };
     $self->{hcols} = \%hcols;
@@ -94,8 +94,8 @@ sub _get_val {
     #so the call to colnumber_from_name fails
     #return undef for db columns (from @cols) not in the @fields list
     #return unless defined $self->colnumber_from_name($name);
-    confess ("col number undef") unless defined $col;
-    $self->{log}->debug( "_get_val \n", Dumper $row);
+    $self->{log}->logconfess ("col number undef") unless defined $col;
+    # $self->{log}->debug( "_get_val \n", Dumper $row);
     $self->{get_val}->( $row, $col, $name );
 
 }
@@ -187,7 +187,7 @@ sub init_apply {
     #my @given  = keys %arg;
     #my @needed = qw(next get_val set_val del_row has_more_row iter);
     my $missing;
-    confess( __PACKAGE__, " init : ", join( " ", @$missing ), " keys with code ref missing" ) if ( defined( $missing = $self->_get_missing_arg( \%arg, [qw(next get_val set_val del_row has_more_row iter status_col)] ) ) );
+     $self->{log}->logconfess( __PACKAGE__, " init : ", join( " ", @$missing ), " keys with code ref missing" ) if ( defined( $missing = $self->_get_missing_arg( \%arg, [qw(next get_val set_val del_row has_more_row iter status_col)] ) ) );
 
     #$self->{log}->debug( Dumper %seen);
     @$self{ ( keys %arg ) } = values %arg;
@@ -231,7 +231,7 @@ Param: the name of the column.
 sub colnumber_from_name {
 
     my ( $self, $fieldname ) = @_;
-    confess "fieldname undef" unless ( defined $fieldname );
+     $self->{log}->logconfess( "fieldname undef") unless ( defined $fieldname );
     
     return $self->{colname_to_number}->{$fieldname}
 
@@ -252,7 +252,7 @@ sub apply {
     #my $row_pos = 0;
     my $row;
     $self->{log}->debug( "apply called dman->row_count : ", $self->{dman}->row_count );
-    $self->{log}->debug( "pkref ", Dumper($pkref) ) if ($pkref);
+    #  $self->{log}->debug( "pkref ", Dumper($pkref) ) if ($pkref);
     my @fields_to_save;
     if ($pkref) {
         my %seen;    #remove from cols the fields received in arg
@@ -372,13 +372,15 @@ A array ref of the names of the columns in the table
 
 The fields definitions of the first column holding the bitmap with Gtk2. Not use with Wx.
 
+=back
+
 =cut
 
 sub setup_fields {
 	my $self = shift;
 	my %args =  ( ref $_[0] eq "HASH" ? %$_[0] : (@_) );
 	my $missing;
-	 confess( __PACKAGE__, "setup_fields : ", join( " ", @$missing ), " keys with value missing" ) if ( defined( $missing = $self->_get_missing_arg( \%args, [qw(allfields cols )] ) ) );
+	  $self->{log}->logconfess( __PACKAGE__, "setup_fields : ", join( " ", @$missing ), " keys with value missing" ) if ( defined( $missing = $self->_get_missing_arg( \%args, [qw(allfields cols )] ) ) );
 	my $fields = $args{allfields};
 
 	    if ( !$fields ) {
@@ -438,7 +440,7 @@ sub setup_fields {
     }
 
 $self->{colname_to_number} = \%name2pos;
-$self->{log}->debug("setup_fields colname_to_number hash:", Dumper %{$self->{colname_to_number}});
+# $self->{log}->debug("setup_fields colname_to_number hash:", Dumper %{$self->{colname_to_number}});
 return ( $fields, \@hiddencols);
 
 
@@ -469,7 +471,7 @@ sub init_combo_setup {
 	my $self = shift;
 	my %args =  ( ref $_[0] eq "HASH" ? %$_[0] : (@_) );
 	my $missing;
-	 confess( __PACKAGE__, " init_combo_setup : ", join( " ", @$missing ), " keys with value missing" ) if ( defined( $missing = $self->_get_missing_arg( \%args, [qw(name fields)] ) ) );
+	  $self->{log}->logconfess( __PACKAGE__, " init_combo_setup : ", join( " ", @$missing ), " keys with value missing" ) if ( defined( $missing = $self->_get_missing_arg( \%args, [qw(name fields)] ) ) );
 	   my $fields = $args{fields};
     my @cols;
     if ( $fields->{fieldnames} ) {
@@ -515,7 +517,7 @@ sub get_liste_def {
 	my $self = shift;
 	my %args =  ( ref $_[0] eq "HASH" ? %$_[0] : (@_) );
 	my $missing;
-	 confess( __PACKAGE__, " get_liste_def : ", join( " ", @$missing ), " keys with value missing" ) if ( defined( $missing = $self->_get_missing_arg( \%args, [qw(fields renderer default_renderer col_ref)] ) ) );
+	  $self->{log}->logconfess( __PACKAGE__, " get_liste_def : ", join( " ", @$missing ), " keys with value missing" ) if ( defined( $missing = $self->_get_missing_arg( \%args, [qw(fields renderer default_renderer col_ref)] ) ) );
     my $fields = $args{fields};
     my @cols = @{$args{col_ref}};
     my $rdbtype = $fieldtype{ $fields->{data_manager}->get_field_type( $cols[0] ) };
@@ -569,7 +571,7 @@ sub setup_combo {
     my $self = shift;
     my %args = ( ref $_[0] eq "HASH" ? %$_[0] : (@_) );
     my $missing;
-    confess( __PACKAGE__, " setup_combo : ", join( " ", @$missing ), " keys with value missing" ) if ( defined( $missing = $self->_get_missing_arg( \%args, [qw(fields name col_ref)] ) ) );
+     $self->{log}->logconfess( __PACKAGE__, " setup_combo : ", join( " ", @$missing ), " keys with value missing" ) if ( defined( $missing = $self->_get_missing_arg( \%args, [qw(fields name col_ref)] ) ) );
     my $fields    = $args{fields};
     my $column_no = $self->colnumber_from_name( $args{name} );
     my $dman      = $fields->{data_manager};
@@ -609,12 +611,12 @@ sub setup_combo {
 }
 
 =head2 _get_missing_arg
-  
+
   sub method
     my $self = shift;
     my %arg = ( ref $_[0] eq "HASH" ? %$_[0] : (@_) );
     my $missing;
-    confess( __PACKAGE__, " method : ", join( " ", @$missing ), " keys with code ref missing" )
+     $self->{log}->logconfess( __PACKAGE__, " method : ", join( " ", @$missing ), " keys with code ref missing" )
            if ( defined( $missing = $self->_get_missing_arg
                ( 
 		    \%arg, 
@@ -674,7 +676,7 @@ FranE<ccedil>ois Rappaz <rappazf@gmail.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2016 by F. Rappaz.  All rights reserved.
+Copyright (c) 2016-2017 by F. Rappaz.  All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
