@@ -4,8 +4,8 @@ our $VERSION = $Gtk2::Ex::DbLinker::DbTools::VERSION;
 use strict;
 use warnings;
 use interface qw(Gtk2::Ex::DbLinker::AbDataManager);
-use Carp qw(carp croak confess cluck);
-use Data::Dumper;
+# use Carp qw(carp croak confess cluck);
+# use Data::Dumper;
 use Try::Tiny;
 
 my %fieldtype = ( tinyint => 'integer', );
@@ -271,7 +271,7 @@ sub save {
             }
         }
         catch {
-            carp("Can't save record : $_");
+             $self->{log}->logcarp("Can't save record : $_");
             $done = 0;
         }
 
@@ -335,7 +335,7 @@ sub delete {
 
         # my $row = $self->{rs}->find( @{$self->{data}[$pos]} );
         my $row = $self->{current_row};
-        if ( !$row->delete ) { croak( " can't delete row at pos " . $pos ) }
+        if ( !$row->delete ) {  $self->{log}->logcroak( " can't delete row at pos " . $pos ) }
 
         splice @{ $self->{data} }, $pos, 1;
         if ( $self->row_count == 0 ) {
@@ -468,7 +468,7 @@ sub _init {
             join( " ", @{ $self->{primary_keys} } )
         );
     }
-    croak("can't work without a pk")
+     $self->{log}->logcroak("can't work without a pk")
       if ( scalar @{ $self->{primary_keys} } == 0 );
     my @apk;
     if ( !defined $self->{ai_primary_keys} ) {
@@ -575,8 +575,8 @@ Instanciation of a DbcManager object is a two step process:
 =item *
 
 use a ResultSet object from the table(s) you want to display
-	
-	 my $rs = $self->{schema}->resultset('Jrn'); 
+
+     my $rs = $self->{schema}->resultset('Jrn'); 
 
 =item * 
 
@@ -598,7 +598,7 @@ To link the data with a Gtk window, the Gtk entries id in the glade file have to
 
 To add a combo box in the form, the first field given in fields array will be used as the return value of the combo. 
 noed is the Gtk2combo id in the glade file and the field's name in the table that received the combo values.
-	 
+
 	my $dman = Gtk2::Ex::DbLinker::DbcDataManager->new(rs => $self->{schema}->resultset('Ed')->search_rs( undef, {order_by => ['nom']} )  );
 
 
@@ -644,7 +644,7 @@ The unique parameter is C<rs>.
 The value for C<rs> is a DBIx::Class::ResultSet object.
 
 		my $rs = $self->{schema}->resultset("Table")->search_rs(undef, {order_by => 'title'});
-		
+
 		my $dman = Gtk2::Ex::DbLinker::DbcDataManager->new({ rs => $rs});
 
 Array references of primary key names and auto incremented primary keys may also be passed using  C<primary_keys>, C<ai_primary_keys> as hash keys. If not given the DbcDataManager uses the primary key from the Ressource object.
@@ -686,6 +686,8 @@ The methods belows are used by the Form module and you should not have to use th
 
 =head2 C<new_row();>
 
+Calls new_result on the underlying recordset and insert defaults values.
+
 =head2 C<save();>
 
 return 1 on success or 0. Check this if you implement a locking mecanism within a Result module with DBIx::Class::OptimisticLocking:
@@ -697,6 +699,8 @@ This will prevent a row from being changed by two users in the same time.
 
 =head2 C<delete();>
 
+Delete the current row.
+
 =head2 C<set_row_pos( $new_pos ); >
 
 change the current row for the row at position C<$new_pos>.
@@ -746,7 +750,7 @@ FranE<ccedil>ois Rappaz <rappazf@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014 by FranE<ccedil>ois Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2014-2017 by FranE<ccedil>ois Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
@@ -755,7 +759,7 @@ L<Gtk2::Ex::DbLinker::Forms>
 L<Gtk2::Ex::DbLinker::Datasheet>
 
 L<DBIx::Class>
-  
+
 =head1 CREDIT
 
 The authors of L<DBIx::Class> !
