@@ -4,8 +4,8 @@ our $VERSION = $Gtk2::Ex::DbLinker::DbTools::VERSION;
 use strict;
 use warnings;
 use interface qw(Gtk2::Ex::DbLinker::AbDataManager);
-use Carp qw(carp croak confess cluck);
-use Data::Dumper;
+# use Carp qw(carp croak confess cluck);
+# use Data::Dumper;
 use Try::Tiny;
 use parent qw(Gtk2::Ex::DbLinker::Recordset);
 
@@ -39,7 +39,7 @@ sub new {
     # $self->{log}->debug("args\n", Dumper(%arg));
 
     $self->{auto_incrementing} = ( defined( $self->{ai_primary_key} ) ? 1 : 0 );
-    confess(
+     $self->{log}->logconfess(
         __PACKAGE__ . ": use ai_primary_key or primary_keys but not both..." )
       if ( defined $self->{ai_primary_key} && defined $self->{primary_keys} );
 
@@ -47,7 +47,7 @@ sub new {
       if ( defined $self->{ai_primary_key} );
 
     if ( !$self->{dbh} ) {
-        confess( __PACKAGE__ . ": constructor missing a dbh!\n" );
+         $self->{log}->logconfess( __PACKAGE__ . ": constructor missing a dbh!\n" );
     }
 
     if ( $self->{sql}->{select_distinct} ) {
@@ -63,7 +63,7 @@ sub new {
         if ( exists $self->{sql}->{pass_through} ) {
             $self->{read_only} = 1;
         } elsif ( !( exists $self->{sql}->{from} ) ) {
-            confess(__PACKAGE__
+             $self->{log}->logconfess(__PACKAGE__
                   . " constructor missing a complete sql definition!\n"
                   . "You either need to specify a pass_through key ( 'pass_through' )\n"
                   . "or a 'from' key\n" );
@@ -90,7 +90,7 @@ sub new {
             $sth->execute;
         }
         catch {
-            croak $self->{dbh}->errstr;
+             $self->{log}->logcroak( $self->{dbh}->errstr);
         };
     }
 
@@ -115,14 +115,14 @@ sub new {
     }
     catch {
 
-        confess $self->{dbh}->errstr;
+         $self->{log}->logconfess($self->{dbh}->errstr);
     };
 
     try {
         $sth->execute;
     }
     catch {
-        confess $self->{dbh}->errstr;
+         $self->{log}->logconfess($self->{dbh}->errstr);
 
     };
 
@@ -147,7 +147,7 @@ sub new {
         if ( $self->{sql}->{bind_values} ) {
             $w{bind_values} = $self->{sql}->{bind_values};
         }
-        $self->{log}->debug( Dumper %w );
+        # $self->{log}->debug( Dumper %w );
         $self->query( \%w );
     } elsif ( $self->{sql}->{pass_through} ) {
         $self->query();
@@ -177,7 +177,7 @@ sub query {
     #} else {
     #	$where = {};
     #}
-    $self->{log}->debug( "query " . Dumper($where) );
+    # $self->{log}->debug( "query " . Dumper($where) );
 
 # $self->{log}->debug("inserting is " . (defined $self->{inserting} && $self->{inserting} ? " true " : " false or undef"));
     if ( $where->{where} ) {
@@ -208,7 +208,7 @@ sub query {
                 { Slice => {} } );
         }
         catch {
-            confess $self->{dbh}->errstr;
+             $self->{log}->logconfess( $self->{dbh}->errstr);
 
         };
         $self->rs_init( $rec, undef );
@@ -250,13 +250,12 @@ sub query {
 
         }
         catch {
-            croak $self->{dbh}->errstr . " " . $local_sql;
+             $self->{log}->logcroak( $self->{dbh}->errstr . " " . $local_sql);
         };
 
 #die $local_sql;
 #$self->{log}->debug("bind values received in the sub :\n" . Dumper( $where->{bind_values}));
-        $self->{log}->debug( "bind values stored in the DM :\n"
-              . Dumper( $self->{sql}->{bind_values} ) );
+        # $self->{log}->debug( "bind values stored in the DM :\n" . Dumper( $self->{sql}->{bind_values} ) );
 
         try {
             if ( $self->{sql}->{bind_values} ) {
@@ -267,7 +266,7 @@ sub query {
 
         }
         catch {
-            confess $self->{dbh}->errstr . " " . $local_sql;
+             $self->{log}->logconfess( $self->{dbh}->errstr . " " . $local_sql);
         };
 
         # $self->{log}->debug("DBI_dman_query sql: $local_sql");
@@ -381,7 +380,7 @@ sub _get_rows_from_batch {
         $data = $self->{dbh}->selectall_arrayref( $local_sql, { Slice => {} } );
     }
     catch {
-        confess $self->{dbh}->errstr . "\n\nLocal SQL was:\n$local_sql";
+         $self->{log}->logconfess( $self->{dbh}->errstr . " Local SQL was:\n$local_sql");
     };
     return $data;
 
@@ -500,7 +499,7 @@ sub save {
         $sth = $self->{dbh}->prepare($update_sql);
 
     }
-    catch { confess $self->{dbh}->errstr; };
+    catch {  $self->{log}->logconfess( $self->{dbh}->errstr) ; };
 
     try {
         $sth->execute(@bind_values);
@@ -739,8 +738,6 @@ C<bind_values> : a array ref of the values corresponding to the place holders in
 
 C<pass_through> :  an sql string that will be executed in the DB. Rows are read only, and can't be deleted or added. The query method can't be used to fetch a new set of rows.
 
-=item * 
-
 =back
 
 =back
@@ -763,7 +760,7 @@ Return the number of rows retrieved.
 	my $dman = $self->{form_a}->get_data_manager();
 
 	$dman->query(where=>"nofm=?", bind_values=>[ $f->{nofm} ]);
-	
+
 	$self->{form_a}->update;
 
 C<query> will not place the recordset cursor, but in the above example C<update> on the Form (or a Datasheet) instance will. Be sure to call C<set_row_pos(0)> on the datamanager object after C<query( ... )> in others situations.
@@ -849,7 +846,7 @@ FranE<ccedil>ois Rappaz <rappazf@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016 by F. Rappaz. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2014-2017 by F. Rappaz. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
