@@ -4,8 +4,8 @@ our $VERSION = $Gtk2::Ex::DbLinker::DbTools::VERSION;
 use strict;
 use warnings;
 use interface qw(Gtk2::Ex::DbLinker::AbDataManager);
-use Carp;
-use Data::Dumper;
+# use Carp;
+# use Data::Dumper;
 
 #$self->{data} holds an array of objects returned by the Rose::DB::Manager's descendant
 #This array is access at set_row_pos( $pos ) when get_field( $id ) is called.
@@ -83,7 +83,7 @@ sub set_row_pos {
     }
     else {
         $found = 0;
-        croak(" position outside rows limits ");
+         $self->{log}->logcroak(" position outside rows limits ");
     }
 
 # $self->{log}->debug("set_row_pos current pos: " . $self->{row}->{pos} . " new pos : " . $pos . " last: " . $self->{row}->{last_row} . " count : " . scalar @{ $self->{data}} );
@@ -223,7 +223,7 @@ sub save {
 =cut
 
     my $done;
-    $done = $row->save or carp("can't save ...\n");
+    $done = $row->save or  $self->{log}->logcarp("can't save ...\n");
     $self->{new_row} = undef;
     return $done;
 }
@@ -249,7 +249,7 @@ sub delete {
     my $pos = $self->{row}->{pos};
     if ( defined $pos ) {    # if ($pos) is false when $pos is 0
         my $row = $self->{data}[$pos];
-        if ( !$row->delete ) { croak( " can't delete row at pos " . $pos ) }
+        if ( !$row->delete ) {  $self->{log}->logcroak( " can't delete row at pos " . $pos ) }
 
         splice @{ $self->{data} }, $pos, 1;
         if ( $self->row_count == 0 ) {
@@ -336,16 +336,16 @@ sub _init_fields_access {
         ->debug( "init_fields_access: fields are " . join( " ", @$aref ) );
     foreach my $id (@$aref) {
         my $c = $meta->column($id);
-        croak("Field $id not found in $meta->class metadata") unless ($c);
+         $self->{log}->logcroak("Field $id not found in $meta->class metadata") unless ($c);
         my $method = $c->method_name('get') || $c->method_name('get_set')
-            or croak("no get/get_set method found for $id");
+            or  $self->{log}->logcroak("no get/get_set method found for $id");
         $self->{fieldGetter}->{ $relname . $id } = $method;
         $self->{log}->debug( "get method for field "
                 . $relname . " "
                 . $id . " : "
                 . $method );
         $method = $c->method_name('set') || $c->method_name('get_set')
-            or croak("no set/get_set method found for $id");
+            or  $self->{log}->logcroak("no set/get_set method found for $id");
         $self->{fieldSetter}->{ $relname . $id }  = $method;
         $self->{fieldsDBType}->{ $relname . $id } = $c->type;
 
@@ -533,7 +533,7 @@ To link the data with a Gtk window, the Gtk entries id in the glade file have to
 
 To add a combo box in the form, the first field given in fields array will be used as the return value of the combo. 
 noed is the Gtk2combo id in the glade file and the field's name in the table that received the combo values.
-	 
+
 	my $dman = Gtk2::Ex::DbLinker::RdbDataManager->new(data => Rdb::Combodata::Manager->get_combodata(sort_by => 'name' ), meta => Rdb::Combodata->meta );
 
 	$self->{linker}->add_combo(
@@ -545,7 +545,7 @@ noed is the Gtk2combo id in the glade file and the field's name in the table tha
 And when all combos or datasheets are added:
 
       $self->{linker}->update;
-  
+
 To change a set of rows in a subform, use and on_changed event of the primary key in the main form and call
 
 		$self->{subform_a}->on_pk_changed($new_primary_key_value);
@@ -557,7 +557,7 @@ In the subform a module:
 		my $data =  Rdb::Mytable::Manager->get_mytable(query => [pk_field => {eq => $value}]);
 		$self->{subform_a}->get_data_manager->query($data);
 		$self->{subform_a}->update;
-		
+
 
 =head1 DESCRIPTION
 
@@ -609,14 +609,9 @@ Return 0 if there is no row or 1 if there are any.
 	$self->{form_a}->get_data_manager->query($data);
 	$self->{form_a}->update;
 
-The methods belows are used by the Form module and you should not have to use them directly.
+=head2 C<new_row();> C<save();> C<delete();>
 
-
-=head2 C<new_row();>
-
-=head2 C<save();>
-
-=head2 C<delete();>
+These methods are used by the Form module and you should not have to use them directly.
 
 =head2 C<set_row_pos( $new_pos ); >
 
@@ -647,11 +642,11 @@ Return the number of rows.
 Return an array of the field names.
 
 =head2 C<get_primarykeys()>;
-	
+
 Return an array of primary key(s) (auto incremented or not).
 
 =head2 C<get_autoinc_primarykeys()>;
-	
+
 Return an array of autoincremented primary key(s) defined by the the 'serial' column's type or undef.
 
 =head1 SUPPORT
@@ -667,7 +662,7 @@ FranE<ccedil>ois Rappaz <rappazf@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014 by F. Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2014-2017 by F. Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
@@ -676,7 +671,7 @@ L<Gtk2::Ex::DbLinker::Forms>
 L<Gtk2::Ex::DbLinker::Datasheet>
 
 L<Rose::DB::Object>
-  
+
 =head1 CREDIT
 
 John Siracusa and the powerfull Rose::DB::Object ORB.
