@@ -4,8 +4,8 @@ our $VERSION = $Gtk2::Ex::DbLinker::DbTools::VERSION;
 
 use strict;
 use warnings;
-use Data::Dumper;
-use Carp;
+# use Data::Dumper;
+# use Carp;
 use Try::Tiny;
 
 my %fieldtype = ( tinyint => "integer", "int" => "integer" );
@@ -262,7 +262,7 @@ sub get_field {
     my ( $self, $fieldname ) = @_;
 
 # $self->{rs_log}->debug("get_field - name : " . $fieldname . "\nRecords: " . (Dumper $self->{records}));
-    carp("get_field($fieldname) called on an empty recordset ! Did you forget to call set_row_pos(0) after query ?"
+     $self->{rs_log}->logcarp("get_field($fieldname) called on an empty recordset ! Did you forget to call set_row_pos(0) after query ?"
     ) unless ( $self->{records} );
     my $data = $self->{records}[ $self->{batch_pos} ]->{$fieldname};
     return $data;
@@ -651,13 +651,15 @@ C<rs_> are used by the inheriting class but not the end user.
 
 The others methods are use by the end user and are described in the inheriting classes.
 
+=back
+
 =head1 AUTHOR
 
 FranE<ccedil>ois Rappaz <rappazf@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2016 by F. Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2016-2017 by F. Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
@@ -666,7 +668,7 @@ L<Gtk2::Ex::DbLinker::SqlADataManager>
 L<Gtk2::Ex::DbLinker::DbiDataManager>
 
 L<Gtk2::Ex::DBI>
- 
+
 =head1 CREDIT
 
 Daniel Kasak's implementation of storing only the pk values for the rows from a select query and getting the actual data for subset of rows.
