@@ -4,8 +4,8 @@ our $VERSION = $Gtk2::Ex::DbLinker::DbTools::VERSION;
 use strict;
 use warnings;
 use interface qw(Gtk2::Ex::DbLinker::AbDataManager);
-use Carp qw(carp croak confess cluck);
-use Data::Dumper;
+# use Carp qw(carp croak confess cluck);
+# use Data::Dumper;
 use SQL::Abstract::More;
 use Try::Tiny;
 
@@ -60,7 +60,7 @@ sub new {
     $$self{defaults}     = $arg{defaults};
 
     # $self->{rs} = Gtk2::Ex::DbLinker::Recordset->new( $self->{aperture} );
-    confess( __PACKAGE__ . ": select_param required" )
+    $self->{log}->logconfess( __PACKAGE__ . ": select_param required" )
       unless ( $self->{select_param} );
     $self->{ai_primary_key} = $arg{ai_primary_key}
       if ( exists( $arg{ai_primary_key} ) )
@@ -70,12 +70,12 @@ sub new {
 
     #$self->{auto_incrementing} = ( defined ($self->{ai_primary_key}) ? 1 : 0);
 
-    confess(
+    $self->{log}->logconfess(
         __PACKAGE__ . ": use ai_primary_key or primary_keys but not both..." )
       if ( defined $self->{ai_primary_key} && defined $self->{primary_keys} );
 
     if ( !$self->{dbh} ) {
-        confess( __PACKAGE__ . ": constructor missing a dbh!\n" );
+        $self->{log}->logconfess( __PACKAGE__ . ": constructor missing a dbh!\n" );
     }
 
     #$self->{cols} = {};
@@ -84,7 +84,7 @@ sub new {
     #     $self->{hcols}= {};
     $self->{server} = $self->{dbh}->get_info(17);
 
-    $self->{log}->debug( "select_param: ", Dumper( $self->{select_param} ) );
+    # $self->{log}->debug( "select_param: ", Dumper( $self->{select_param} ) );
     $self->{log}->debug( "select_param ref: ", ref $self->{select_param} );
 
     if ( ref $self->{select_param} eq "SCALAR" ) {
@@ -97,7 +97,7 @@ sub new {
             $sth->execute;
         }
         catch {
-            confess( $self->{log}->error( $self->{dbh}->errstr ) );
+            $self->{log}->logconfess( $self->{log}->error( $self->{dbh}->errstr ) );
         };
 
         $self->_use_sth_info($sth);
@@ -106,7 +106,7 @@ sub new {
     } else {
         $self->{sql}   = SQL::Abstract::More->new( %{ $self->{new_param} } );
         $self->{table} = $self->_get_tablename;
-        $self->{log}->debug( "Table found: ", Dumper( $self->{table} ) );
+        # $self->{log}->debug( "Table found: ", Dumper( $self->{table} ) );
         $self->_init_cols;
         $self->{log}->debug( "cols: ", join( " ", @{ $self->{cols} } ), "\n" );
         $self->{auto_incrementing} =
@@ -164,7 +164,7 @@ sub query {
 
     #$self->{select_param} = $select;
 
-    $self->{log}->debug("query: ", Dumper($select));
+    #  $self->{log}->debug("query: ", Dumper($select));
 
     if ( $self->{before_query} ) {
         $self->{before_query}();
@@ -210,7 +210,7 @@ sub query {
 
 # $self->{log}->debug("query : " . $primary_key . " value : " . $row[$key_no] );
 # if $row[$key_no] is 0 the test failed but a pk could have this value...
-            croak( __PACKAGE__
+             $self->{log}->logcroak( __PACKAGE__
                   . ": no value found for primary key $pk .. check the sql command"
             ) unless ( defined $row[$key_no] );
 
@@ -392,7 +392,7 @@ sub save {
     }    #foreach
 
     # my $update_sql;
-    $self->{log}->debug( "new values: ", Dumper %new_values );
+    $self->{log}->debug( "new values: ", join(" ", %new_values) );
     if ( $self->{inserting} ) {
 
 #$update_sql = "insert into " . $self->{sql}->{from} . " ( " . join( ",", @fieldlist, ) . " )" . " values ( " . "?," x ( @fieldlist - 1 ) . "? )";
@@ -421,7 +421,7 @@ sub save {
         $self->{log}->debug(
             "updating ", $table,
             " at rows with pks : ",
-            Dumper %pk_values
+            join(" ", %pk_values)
         );
 
         # run the update
@@ -535,7 +535,7 @@ sub _init_cols {
     my %seen;
     my @cols =
       ref $args->{-columns} ? @{ $args->{-columns} } : $args->{-columns};
-    $self->{log}->debug( "_init_cols ", Dumper @cols );
+    $self->{log}->debug( "_init_cols ",  defined $cols[0] ? join(" ", @cols) : " undef");
     if ( $cols[0] ) {
         my @post_select;
         push @post_select, shift @cols while @cols && $cols[0] =~ s/^-//;
@@ -611,7 +611,7 @@ sub _get_tablename {
         my @join_args = @{ $args{-from} };
         shift @join_args;    # drop initial '-join'
         my $href = $self->{sql}->join(@join_args);
-        $self->{log}->debug( Dumper($href) );
+        # $self->{log}->debug( Dumper($href) );
         my $alias_or_name = $href->{name};
         $tableinfo = $href->{aliased_tables}->{$alias_or_name};
         $tableinfo = ( defined $tableinfo ? $tableinfo : $alias_or_name );
@@ -727,7 +727,7 @@ Parameters are
 =over
 
 =item *
- 
+
 C<dbh>, 
 
 =item *
@@ -817,6 +817,8 @@ Pass a list or a hash reference to save when a value has to be saved in the data
 
 =head2 C<new_row();>
 
+Insert a new row and set the default values.
+
 =head2 C<delete();>
 
 Delete the row $pos once C<set_row_pos( $pos )> has been called.
@@ -870,14 +872,14 @@ FranE<ccedil>ois Rappaz <rappazf@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2016 by F. Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2016-2017 by F. Rappaz.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
 L<Gtk2::Ex::DbLinker::Forms>
 
 L<Gtk2::Ex::DbLinker::Datasheet>
- 
+
 =head1 CREDIT
 
 Laurent Dami for its robust SQL::Abstract::More module !
